Modules
Structs
- Included
Ranges Error - An error that occurred in
Parser::set_included_ranges. - Input
Edit - A summary of a change to a text document.
- Language
- An opaque object that defines how to parse a particular language. The code
for each
Languageis generated by the Tree-sitter CLI. - Language
Error - An error that occurred when trying to assign an incompatible
Languageto aParser. - Language
Ref - Lookahead
Iterator - A stateful object that is used to look up symbols valid in a specific parse state
- Lossy
Utf8 - Node
- A single node within a syntax
Tree. - Parse
Error - Parser
- A stateful object that this is used to produce a
Treebased on some source code. - Point
- A position in a multi-line text document, in terms of rows and columns.
- Query
- A set of patterns that match nodes in a syntax tree.
- Query
Capture - A particular
Nodethat has been captured with a particular name within aQuery. - Query
Captures - A sequence of
QueryCaptures associated with a givenQueryCursor. - Query
Cursor - A stateful object for executing a
Queryon a syntaxTree. - Query
Error - An error that occurred when trying to create a
Query. - Query
Match - A match of a
Queryto a particular set ofNodes. - Query
Matches - A sequence of
QueryMatches associated with a givenQueryCursor. - Query
Predicate - A key-value pair associated with a particular pattern in a
Query. - Query
Property - A key-value pair associated with a particular pattern in a
Query. - Range
- A range of positions in a multi-line text document, both in terms of bytes and of rows and columns.
- Tree
- A tree that represents the syntactic structure of a source code file.
- Tree
Cursor - A stateful object for walking a syntax
Treeefficiently.
Enums
- Capture
Quantifier - A quantifier for captures
- LogType
- A type of log message.
- Query
Error Kind - Query
Predicate Arg
Constants
- ARRAY_
HEADER - LANGUAGE_
VERSION - The latest ABI version that is supported by the current version of the library.
- MIN_
COMPATIBLE_ LANGUAGE_ VERSION - The earliest ABI version that is supported by the current version of the library.
- PARSER_
HEADER
Traits
Functions
- parse_
source - set_
allocator ⚠ - Sets the memory allocation functions that the core library should use.
- wasm_
stdlib_ symbols